@@ -7,7 +7,6 @@ from pulpcore.plugin.serializers import (
     ContentChecksumSerializer,
     DetailRelatedField,
     DistributionSerializer,
-    FilesystemExporterSerializer,
     PublicationSerializer,
     RemoteSerializer,
     RepositorySerializer,
@@ -17,7 +16,6 @@ from pulpcore.plugin.serializers import (
 from pulp_file.app.models import (
     FileContent,
     FileDistribution,
-    FileFilesystemExporter,
     FileRemote,
     FileRepository,
     FilePublication,
@@ -135,16 +133,28 @@ class FileDistributionSerializer(DistributionSerializer):
         allow_null=True,
     )
 
+    def validate(self, data):
+        """
+        Ensure publication and repository are not set at the same time.
+
+        This is needed here till https://pulp.plan.io/issues/8761 is resolved.
+        """
+        data = super().validate(data)
+        repository_provided = data.get("repository", None)
+        publication_provided = data.get("publication", None)
+
+        if repository_provided and publication_provided:
+            raise serializers.ValidationError(
+                _(
+                    "Only one of the attributes 'repository' and 'publication' "
+                    "may be used simultaneously."
+                )
+            )
+        if repository_provided or publication_provided:
+            data["repository"] = repository_provided
+            data["publication"] = publication_provided
+        return data
+
     class Meta:
         fields = DistributionSerializer.Meta.fields + ("publication",)
         model = FileDistribution
-
-
-class FileFilesystemExporterSerializer(FilesystemExporterSerializer):
-    """
-    Serializer for File file system exporters.
-    """
-
-    class Meta:
-        fields = FilesystemExporterSerializer.Meta.fields
-        model = FileFilesystemExporter
